@@ -8,24 +8,36 @@ import argparse
 import importlib.metadata
 import sys
 from datetime import datetime, timedelta, timezone
+from typing import TypedDict
 
 from reviewtally.exceptions.local_exceptions import MalformedDateError
 
 
+class CommandLineArgs(TypedDict):
+    """Type definition for cli arguments returned by parse_cmd_line."""
+
+    org_name: str
+    start_date: datetime
+    end_date: datetime
+    languages: list[str]
+    metrics: list[str]
+    sprint_analysis: bool
+    output_path: str | None
+    plot_sprint: bool
+    chart_type: str
+    chart_metrics: list[str]
+    save_plot: str | None
+    plot_individual: bool
+    individual_chart_metric: str
+    use_cache: bool
+
+
 def print_toml_version() -> None:
     version = importlib.metadata.version("review-tally")
     print(f"Current version is {version}")  # noqa: T201
 
 
-def parse_cmd_line() -> tuple[
-    str,
-    datetime,
-    datetime,
-    list[str],
-    list[str],
-    bool,
-    str | None,
-]:  # type: ignore[return-value]
+def parse_cmd_line() -> CommandLineArgs:  # noqa: C901, PLR0912, PLR0915
     description = """Get pull requests for the organization between dates
     and the reviewers for each pull request. The environment must declare
     a GTIHUB_TOKEN variable with a valid GitHub token.
@@ -64,7 +76,8 @@ def parse_cmd_line() -> tuple[
     # add the metrics selection argument
     metrics_help = (
         "Comma-separated list of metrics to display "
-        "(reviews,comments,avg-comments,engagement,thoroughness,response-time,completion-time,active-days)"
+        "(reviews,comments,avg-comments,engagement,thoroughness,"
+        "response-time,completion-time,active-days)"
     )
     parser.add_argument(
         "-m",
@@ -92,6 +105,62 @@ def parse_cmd_line() -> tuple[
         "--output-path",
         help="Output CSV file path for sprint data",
     )
+
+    # plotting options for sprint analysis
+    parser.add_argument(
+        "--plot-sprint",
+        action="store_true",
+        help=(
+            "Plot sprint metrics as an interactive chart (opens browser)"
+        ),
+    )
+    parser.add_argument(
+        "--chart-type",
+        choices=["bar", "line"],
+        default="bar",
+        help="Chart type for sprint metrics (bar or line)",
+    )
+    parser.add_argument(
+        "--chart-metrics",
+        default="total_reviews,total_comments",
+        help=(
+            "Comma-separated sprint metrics to plot. "
+            "Supported: total_reviews,total_comments,unique_reviewers,"
+            "avg_comments_per_review,reviews_per_reviewer,"
+            "avg_response_time_hours,avg_completion_time_hours,"
+            "active_review_days"
+        ),
+    )
+    parser.add_argument(
+        "--save-plot",
+        help="Optional path to save the interactive HTML chart",
+    )
+
+    # plotting options for individual analysis
+    parser.add_argument(
+        "--plot-individual",
+        action="store_true",
+        help=(
+            "Plot individual reviewer metrics as a pie chart (opens browser)"
+        ),
+    )
+    parser.add_argument(
+        "--individual-chart-metric",
+        choices=["reviews", "comments", "avg_comments_per_review",
+                "engagement_level", "thoroughness_score",
+                "avg_response_time_hours", "avg_completion_time_hours",
+                "active_review_days"],
+        default="reviews",
+        help="Metric to visualize in individual pie chart",
+    )
+
+    # caching options
+    parser.add_argument(
+        "--no-cache",
+        action="store_true",
+        help="Disable PR review caching (always fetch fresh data from API)",
+    )
+
     args = parser.parse_args()
     # catch ValueError if the date format is not correct
     try:
@@ -130,12 +199,25 @@ def parse_cmd_line() -> tuple[
     else:
         metrics = [args.metrics]
 
-    return (
-        args.org,
-        start_date,
-        end_date,
-        languages,
-        metrics,
-        args.sprint_analysis,
-        args.output_path,
+    # parse chart metrics argument
+    if args.chart_metrics and "," in args.chart_metrics:
+        chart_metrics = args.chart_metrics.split(",")
+    else:
+        chart_metrics = [args.chart_metrics]
+
+    return CommandLineArgs(
+        org_name=args.org,
+        start_date=start_date,
+        end_date=end_date,
+        languages=languages,
+        metrics=metrics,
+        sprint_analysis=args.sprint_analysis,
+        output_path=args.output_path,
+        plot_sprint=args.plot_sprint,
+        chart_type=args.chart_type,
+        chart_metrics=chart_metrics,
+        save_plot=args.save_plot,
+        plot_individual=args.plot_individual,
+        individual_chart_metric=args.individual_chart_metric,
+        use_cache=not args.no_cache,
     )
